@@ -2,9 +2,9 @@
 
 /*
  * File "mmc_format.c" is part of the UDFclient toolkit.
- * File $Id: mmc_format.c,v 1.12 2008/10/13 12:35:47 reinoud Exp $ $Name:  $
+ * File $Id: mmc_format.c,v 1.18 2022/02/06 14:29:25 reinoud Exp $ $Name:  $
  *
- * Copyright (c) 2003, 2004, 2005, 2006, 2011
+ * Copyright (c) 2003, 2004, 2005, 2006, 2011, 2020
  * 	Reinoud Zandijk <reinoud@netbsd.org>
  * All rights reserved.
  *
@@ -159,7 +159,7 @@ static char
 
 	switch (profile) {
 	case 0x00 : return "Unknown[0] profile";
-	case 0x01 : return "Non removeable disc";
+	case 0x01 : return "Non removable disc";
 	case 0x02 : return "Removable disc";
 	case 0x03 : return "Magneto Optical with sector erase";
 	case 0x04 : return "Magneto Optical write once";
@@ -348,7 +348,7 @@ print_format(int format_tp, uint32_t num_blks, uint32_t param,
 		break;
 	case  0x05 :
 		format_str = "fixed length zone'd format";
-		nblks_str  = "zone lenght";
+		nblks_str  = "zone length";
 		param_str  = "last zone number";
 		*supported = 0;
 		break;
@@ -515,11 +515,8 @@ uscsi_format_cdrw_mode7(struct uscsi_dev *dev, uint32_t blocks)
 {
 	scsicmd cmd;
 	struct uscsi_sense sense;
-	uint32_t param;
 	uint8_t  buffer[16];
-	int cnt, error;
-
-	param = cnt = 0;
+	int error;
 
 	if (blocks % 32) {
 		blocks -= blocks % 32;
@@ -629,7 +626,7 @@ uscsi_format_disc(struct uscsi_dev *dev, int immed, int format_type,
 	if (error)
 		return error;
 
-	if (immed)
+	if (!immed)
 		uscsi_waitop(dev);
 
 	return 0;
@@ -738,64 +735,64 @@ main(int argc, char *argv[])
 	uscsilib_verbose    = 0;
 	while ((flag = getopt(argc, argv, "BFMRGSwpsc:rhHIX:Ob:D")) != -1) {
 		switch (flag) {
-			case 'B' :
-				blank = 1;
-				break;
-			case 'F' :
-				format = 1;
-				break;
-			case 'M' :
-				mrw = 1;
-				break;
-			case 'R' :
-				restart_format = 1;
-				break;
-			case 'G' :
-				grow_session = 1;
-				break;
-			case 'S' :
-				grow_spare = 1;
-				break;
-			case 'w' :
-				wait_until_finished = 1;
-				break;
-			case 'p' :
-				packet_wr = 1;
-				break;
-			case 's' :
-				spare = 1;
-				break;
-			case 'c' :
-				certification = atoi(optarg);
-				break;
-			case 'r' :
-				cmplist = 1;
-				break;
-			case 'h' :
-			case 'H' :
-				display_usage = 1;
-			case 'I' :
-				inquiry = 1;
-				break;
-			case 'X' :
-				/* TODO parse expert mode string */
-				printf("-X not implemented yet\n");
-				expert = 1;
-				exit(1);
-				break;
-			case 'O' :
-				/* oldtimer CD-RW format */
-				oldtimer = 1;
-				format   = 1;
-				break;
-			case 'b' :
-				blockingnr = atoi(optarg);
-				break;
-			case 'D' :
-				uscsilib_verbose = 1;
-				break;
-			default :
-				return usage(progname);
+		case 'B' :
+			blank = 1;
+			break;
+		case 'F' :
+			format = 1;
+			break;
+		case 'M' :
+			mrw = 1;
+			break;
+		case 'R' :
+			restart_format = 1;
+			break;
+		case 'G' :
+			grow_session = 1;
+			break;
+		case 'S' :
+			grow_spare = 1;
+			break;
+		case 'w' :
+			wait_until_finished = 1;
+			break;
+		case 'p' :
+			packet_wr = 1;
+			break;
+		case 's' :
+			spare = 1;
+			break;
+		case 'c' :
+			certification = atoi(optarg);
+			break;
+		case 'r' :
+			cmplist = 1;
+			break;
+		case 'h' :
+		case 'H' :
+			display_usage = 1;
+		case 'I' :
+			inquiry = 1;
+			break;
+		case 'X' :
+			/* TODO parse expert mode string */
+			printf("-X not implemented yet\n");
+			expert = 1;
+			exit(1);
+			break;
+		case 'O' :
+			/* oldtimer CD-RW format */
+			oldtimer = 1;
+			format   = 1;
+			break;
+		case 'b' :
+			blockingnr = atoi(optarg);
+			break;
+		case 'D' :
+			uscsilib_verbose = 1;
+			break;
+		default :
+			return usage(progname);
 		}
 	}
 	argv += optind;
